import { ISession, IProfile, ISocialUser, IUser, ISocialConnect, IVersionedHash, INewUser, ISesionUpdateRequest, ISessionCreateRequest } from '@identity-stack/core';
import { IDataContext } from './data-context';
export interface IUserRepository {
    userExists(username: string, context?: IDataContext): Promise<boolean>;
    findUserById(id: string): Promise<IUser | never>;
    findUserByEmail(email: string): Promise<IUser | never>;
    findUserByUsername(username: string, context?: IDataContext): Promise<IUser | never>;
    findPasswordHashByUsername(username: string, context?: IDataContext): Promise<IVersionedHash | never>;
    createUser(newUser: INewUser, context?: IDataContext): Promise<void>;
    setUserPassword(username: string, passwordHash: IVersionedHash, context?: IDataContext): Promise<void>;
    updateUserEmailVerified(username: string, email: string, verified: boolean, context: IDataContext): Promise<void>;
}
export interface ITokenRepository {
    findUsernameVerificationTokenHashes(username: string, context?: IDataContext): Promise<IVersionedHash[]>;
    findEmailVerificationTokenHashes(username: string, email: string, context?: IDataContext): Promise<IVersionedHash[]>;
    addEmailVerificationTokenHash(username: string, email: string, verificationTokenHash: IVersionedHash, context?: IDataContext): Promise<void>;
    addUsernameVerificationTokenHash(username: string, verificationTokenHash: IVersionedHash, context?: IDataContext): Promise<void>;
    deleteAllVerificationTokenHashes(username: string, context?: IDataContext): Promise<void>;
    findPasswordResetTokenHashes(username: string, context?: IDataContext): Promise<IVersionedHash[]>;
    addPasswordResetTokenHash(username: string, passwordResetTokenHash: IVersionedHash, context?: IDataContext): Promise<void>;
    deleteAllPasswordResetTokenHashes(username: string, context?: IDataContext): Promise<void>;
}
export interface IProfileRepository {
    createProfile(displayName: string, context?: any): Promise<number>;
    getProfileById(id: string): Promise<IProfile | null>;
}
export interface ISocialLoginRepsitory {
    getOrCreateSocialUser(connect: ISocialConnect, context?: any): Promise<ISocialUser>;
}
export interface IISessionRepository {
    findSessionById(sessionId: string): Promise<ISession>;
    createSession(session: ISessionCreateRequest, context?: IDataContext): Promise<string>;
    updateSession(sessionUpdateRequest: ISesionUpdateRequest, context?: IDataContext): Promise<void>;
    invalidateSession(sessionId: string): Promise<void>;
    invalidateAllSessions(userId: string): Promise<void>;
}
export interface IIdentityRepository extends IUserRepository, ITokenRepository, IProfileRepository, ISocialLoginRepsitory {
}
