import { IAccountsCommonConfiguration, ISession, IUser, IPassword, ICreateUser, ILoginUserIdentity, IOAuthProvider, IAuthOptions, PROVIDERS_NAME, IServerConfiguration } from '@identity-stack/core';
import { JwtAlgorithmTypes } from '@identity-stack/jwt';
import { PrepareMailFunction, SendMailFunction } from './email';
export declare type PasswordAuthenticator = (user: ILoginUserIdentity, password: IPassword) => Promise<any>;
export declare type ResumeSessionValidator = (user: IUser, session: ISession) => Promise<any>;
export interface ITokenConfig {
    accessToken?: {
        expiresIn: number;
    };
    codeToken?: {
        expiresIn: number;
    };
    refreshToken?: {
        expiresIn: number;
    };
    idToken?: {
        expiresIn: number;
    };
}
export declare type UserObjectSanitizerFunction = (user: IUser, omitFunction: (userDoc: object) => IUser, pickFunction: (userDoc: object) => IUser) => any;
export interface IAuthorizationServerConfiguration extends IAccountsCommonConfiguration, IServerConfiguration {
    tokenSecret?: string;
    jwtAlgorithm?: JwtAlgorithmTypes;
    tokenConfigs?: ITokenConfig;
    passwordAuthenticator?: PasswordAuthenticator;
    resumeSessionValidator?: ResumeSessionValidator;
    prepareMail?: PrepareMailFunction;
    sendMail?: SendMailFunction;
    email?: object;
    emailTokensExpiry?: number;
    validateNewUser?: (user: ICreateUser) => Promise<boolean>;
    userObjectSanitizer?: UserObjectSanitizerFunction;
    allowedLoginFields?: string[];
    providers: Map<(keyof typeof PROVIDERS_NAME), IOAuthProvider>;
    auth: IAuthOptions;
}
