/// <reference types="bunyan" />
import { VersioningHasher } from '../security';
import * as Logger from 'bunyan';
import { IClientRepository, IClientService, ISecretGenerator } from '../interfaces';
import { AbstractClientOptions } from '../models';
import { IClient, ClientType, IClientOptions } from '@identity-stack/core';
export declare class ClientService implements IClientService {
    private clientRepo;
    private hasher;
    private secretGenerator;
    private clientOptionTypes;
    private logger;
    constructor(clientRepo: IClientRepository, hasher: VersioningHasher, secretGenerator: ISecretGenerator, clientOptionTypes: Array<AbstractClientOptions>, logger: Logger);
    verifyClient(clientId: string, clientSecret: string): Promise<IClient>;
    createClient(name: string, clientType: ClientType): Promise<IClient>;
    updateClient(clientId: string, clientOptions: IClientOptions): Promise<IClient>;
    refreshAndPersistSecret(clientId: string, requireClientSecretHashed: boolean): Promise<{
        clientSecret: string;
        secretMask: string;
    }>;
    findClient(clientId: string, redirectURI: string): Promise<IClient>;
    unsecuredFindClient(clientId: string): Promise<IClient>;
    private refreshSecret();
    private hashSecret(clientSecret, requireHash);
    private convertClientHashToClient(clientHash);
}
